<?php
/**
 * Customizer Option - Author
 *
 * @package One_Hive
 */

$defaults = one_hive_get_default_theme_options();

$pages = one_hive_get_pages();

$background_choices = one_hive_get_background_choices();

// Section - Author
$wp_customize->add_section( 'one_hive_author_section', array(
	'priority'		=> 20,
	'title'			=> esc_html__( 'Author Section', 'one-hive' ),
	'panel'			=> 'one_hive_home_page_options'	
) );

// Enable Author
$wp_customize->add_setting( 'one_hive_enable_author_section', array(
	'sanitize_callback'	=> 'one_hive_sanitize_checkbox',
	'default'			=> $defaults['one_hive_enable_author_section'],
) );

$wp_customize->add_control( 'one_hive_enable_author_section', array(
	'label'				=> esc_html__( 'Enable Author Section', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'type'				=> 'checkbox',
) );

// Author Section ID
$wp_customize->add_setting( 'one_hive_author_section_id', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'			=> $defaults['one_hive_author_section_id'],
) );

$wp_customize->add_control( 'one_hive_author_section_id', array(
	'label'				=> esc_html__( 'Author Section ID', 'one-hive' ),
	'description'		=> esc_html__( 'Author Section ID is used to navigate to author section from Menu Item. It will be active when your site is one page site.', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'type'				=> 'text',
	'active_callback'	=> 'one_hive_enable_author_section_id'
) );

// Author Background
$wp_customize->add_setting( 'one_hive_author_background', array(
	'sanitize_callback'	=> 'one_hive_sanitize_select',
	'default'			=> $defaults['one_hive_author_background'],
) );

$wp_customize->add_control( 'one_hive_author_background', array(
	'label'				=> esc_html__( 'Author Background', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'type'				=> 'select',
	'choices' 			=> $background_choices,
	'active_callback'	=> 'one_hive_is_active_author_section'
) );

// Author Background Image
$wp_customize->add_setting( 'one_hive_author_image_background', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'			=> $defaults['one_hive_author_image_background'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'one_hive_author_image_background', array(
	'label'				=> esc_html__( 'Author Background Image', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'active_callback'	=> 'one_hive_is_image_author_section_background'
) ) );

// Author Background Color
$wp_customize->add_setting( 'one_hive_author_color_background', array(
	'sanitize_callback'	=> 'sanitize_hex_color',
	'default'			=> $defaults['one_hive_author_color_background'],
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'one_hive_author_color_background', array(
	'label'				=> esc_html__( 'Author Background Color', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'active_callback'	=> 'one_hive_is_color_author_section_background'
) ) );

// Author Page
$wp_customize->add_setting( 'one_hive_author_page', array(
	'sanitize_callback'	=> 'one_hive_sanitize_dropdown_pages',
	'default'			=> $defaults['one_hive_author_page'],
) );

$wp_customize->add_control( 'one_hive_author_page', array(
	'label'				=> esc_html__( 'Author Page', 'one-hive' ),
	'description'		=> esc_html__( 'Page Contents are used for the image and author content', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'type'				=> 'select',
	'choices'			=> $pages,
	'active_callback'	=> 'one_hive_is_active_author_section'
) );

// Author Facebook Link
$wp_customize->add_setting( 'one_hive_author_facebook_link', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'			=> $defaults['one_hive_author_facebook_link'],
) );

$wp_customize->add_control( 'one_hive_author_facebook_link', array(
	'label'				=> esc_html__( 'Author Facebook Link', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'type'				=> 'url',
	'active_callback'	=> 'one_hive_is_active_author_section'
) );

// Author Twitter Link
$wp_customize->add_setting( 'one_hive_author_twitter_link', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'			=> $defaults['one_hive_author_twitter_link'],
) );

$wp_customize->add_control( 'one_hive_author_twitter_link', array(
	'label'				=> esc_html__( 'Author Twitter Link', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'type'				=> 'url',
	'active_callback'	=> 'one_hive_is_active_author_section'
) );

// Author Dribble Link
$wp_customize->add_setting( 'one_hive_author_dribble_link', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'			=> $defaults['one_hive_author_dribble_link'],
) );

$wp_customize->add_control( 'one_hive_author_dribble_link', array(
	'label'				=> esc_html__( 'Author Dribble Link', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'type'				=> 'url',
	'active_callback'	=> 'one_hive_is_active_author_section'
) );

// Author Behance Link
$wp_customize->add_setting( 'one_hive_author_behance_link', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'			=> $defaults['one_hive_author_behance_link'],
) );

$wp_customize->add_control( 'one_hive_author_behance_link', array(
	'label'				=> esc_html__( 'Author Behance Link', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'type'				=> 'url',
	'active_callback'	=> 'one_hive_is_active_author_section'
) );

// Author Youtube Link
$wp_customize->add_setting( 'one_hive_author_youtube_link', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'			=> $defaults['one_hive_author_youtube_link'],
) );

$wp_customize->add_control( 'one_hive_author_youtube_link', array(
	'label'				=> esc_html__( 'Author Youtube Link', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'type'				=> 'url',
	'active_callback'	=> 'one_hive_is_active_author_section'
) );

// Author Linkedin Link
$wp_customize->add_setting( 'one_hive_author_linkedin_link', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'			=> $defaults['one_hive_author_linkedin_link'],
) );

$wp_customize->add_control( 'one_hive_author_linkedin_link', array(
	'label'				=> esc_html__( 'Author Linkedin Link', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'type'				=> 'url',
	'active_callback'	=> 'one_hive_is_active_author_section'
) );

// Author Instagram Link
$wp_customize->add_setting( 'one_hive_author_instagram_link', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'			=> $defaults['one_hive_author_instagram_link'],
) );

$wp_customize->add_control( 'one_hive_author_instagram_link', array(
	'label'				=> esc_html__( 'Author Instagram Link', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'type'				=> 'url',
	'active_callback'	=> 'one_hive_is_active_author_section'
) );

// Author Pinterest Link
$wp_customize->add_setting( 'one_hive_author_pinterest_link', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'			=> $defaults['one_hive_author_pinterest_link'],
) );

$wp_customize->add_control( 'one_hive_author_pinterest_link', array(
	'label'				=> esc_html__( 'Author Pinterest Link', 'one-hive' ),
	'section'			=> 'one_hive_author_section',
	'type'				=> 'url',
	'active_callback'	=> 'one_hive_is_active_author_section'
) );

// Author Skills
$wp_customize->add_setting( 'one_hive_author_skills', array(
	'sanitize_callback' => 'one_hive_repeater_data_field',
	'transport' => 'postMessage',
) );

$wp_customize->add_control( new One_Hive_Repeater_Control( $wp_customize, 'one_hive_author_skills', array(
    'label' 		=> esc_html__('Author Skill', 'one-hive'),
    'description'   => '',
    'section'       => 'one_hive_author_section',
    'live_title_id' => '', // apply for unput text and textarea only
    'title_format'  => '', // [live_title]
    'max_item'      => 4, // Maximum item can add
    'limited_msg' 	=> esc_html__( 'Only four skills can be added.', 'one-hive' ),
    'fields'    => array(
    	'one_hive_author_skill_title'  => array(
        	'title' => esc_html__('Skill Title', 'one-hive'),
        	'type'  => 'text',
        ),
        'one_hive_author_skill_level'  => array(
        	'title' => esc_html__('Skill Level', 'one-hive'),
        	'type'  => 'number',
        ),
        'one_hive_author_skill_color'  => array(
        	'title' => esc_html__('Skill Color', 'one-hive'),
        	'type'  => 'color',
        ),
    ),
    'active_callback'	=> 'one_hive_is_active_author_section'
) ) );

